@@ -1,7 +1,7 @@
 package Sah::Schema::ean8;
 
 our $DATE = '2019-11-28'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [str => {
     summary => 'EAN-8 number',
@@ -13,7 +13,7 @@ Checksum digit must be valid.
 
 _
     match => '\A[0-9]{8}\z',
-    'x.perl.coerce_rules' => ['str_to_ean8'],
+    'x.perl.coerce_rules' => ['From_str::to_ean8'],
 }, {}];
 
 1;
@@ -31,7 +31,7 @@ Sah::Schema::ean8 - EAN-8 number
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::ean8 (from Perl distribution Sah-Schemas-EAN), released on 2019-11-28.
+This document describes version 0.005 of Sah::Schema::ean8 (from Perl distribution Sah-Schemas-EAN), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
